%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
%                         LaTeX DOCUMENT CLASS                           %
%                                                                        %
%                       for preparing papers to                          %
%                                                                        %
%       8th CONFERENCE DIAGNOSTICS OF PROCESSES AND SYSTEMS, DPS 2007    %
%                                                                        %
%                        Zielona Gra 14.03.2007                         %
%                                                                        %
%                          (c) Krzysztof Patan                           %
%                  e-mail: k.patan@issi.uz.zgora.pl                      %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\typeout{Document Style `dps' <2007>.}

\NeedsTeXFormat{LaTeX2e}[1996/12/01]
\ProvidesClass{dps}[2007/03/14]

\LoadClass[twoside,onecolumn,a4paper,10pt]{book}
\RequirePackage{times}
\RequirePackage{amsmath}

%%%%%%%%%%%%%%%%%%%%%%%% Pages numbering %%%%%%%%%%%%%%%%%%%%%%

\newcommand{\Startpage}[1]{\gdef\@Startpage{#1}}
\let\@Startpage\@empty

%%%%%%%%%%%%%%%%%%%%%%%% Page layout %%%%%%%%%%%%%%%%%%%%%%%%%%
\addtolength{\textwidth}{7mm}
\addtolength{\evensidemargin}{-8mm}
\newlength{\abstractwidth}
\setlength\abstractwidth{106mm}
%%%%%%%%%%%%%%%%%%%%%%%% Title page %%%%%%%%%%%%%%%%%%%%%%%%%%%

\renewcommand{\title}[2][]{
 \def\@temp{#1}
 \gdef\@title{#2}
 \ifx\@temp\@empty 
   \gdef\head@title{#2}
 \else
   \gdef\head@title{#1}
 \fi 
}

\renewcommand{\author}[2][]{
 \def\@temp{#1}
 \gdef\@autor{#2}
 \ifx\@temp\@empty 
   \gdef\head@author{#2}
 \else
   \gdef\head@author{#1}
 \fi 
}

\newcommand{\address}[1]{\gdef\@adres{#1}}
 
\newbox\abstractbox
\def\abstract{\global\setbox\abstractbox=\hbox\bgroup
  \begin{minipage}{\abstractwidth}{\small \sf Abstract.}}
\def\endabstract{\end{minipage}\egroup}

\newbox\keywordbox
\def\keywords{\global\setbox\keywordbox=\hbox\bgroup
        \begin{minipage}[t]{\abstractwidth}{\small \sf Keywords:}}
\def\endkeywords{\end{minipage}\egroup}

%%%%%%%%%%%%%%%%%%%%%%%% Headers %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\ps@plain{
 \let\@mkboth\markboth
 \def\@oddhead{}
 \def\@evenhead{}
 \def\@oddfoot{}
 \def\@evenfoot{}
}

\def\ps@dps{
 \let\@mkboth\markboth
 \let\@oddfoot\@empty
 \let\@evenfoot\@empty
 \def\@oddhead{\vtop{\hb@xt@\textwidth{{\small \mbox{\head@title} \hfil}\thepage}\vskip2pt\hrule\vskip-2.4pt}}
 \def\@evenhead{\vtop{\hb@xt@\textwidth{\thepage \small \hfil{\head@author}}\vskip2pt\hrule\vskip-2.4pt}}
}

\pagestyle{dps}

%%%%%%%%%%%%%%%%%%%%%%%% MAKETITLE %%%%%%%%%%%%%%%%%%%%%%%

\renewcommand\maketitle{\newpage\thispagestyle{plain}
      \ifx\@Startpage\@empty\setcounter{page}{1}
      \else\setcounter{page}{\@Startpage}
      \fi
      \begin{center}
       \begin{minipage}{\abstractwidth}\centering
        \vskip20pt
        \let\footnote\thanks
	{\Large \sf \@title \par}
	\vskip20pt
	{\normalsize \sf \@autor}
	\vskip15pt
	{\small \sf \@adres}
	\vskip30pt
	\usebox{\abstractbox}
	\vskip20pt
	\usebox{\keywordbox}
	\end{minipage}	
      \end{center}\par
      \@thanks
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Sections %%%%%%%%%%%%%%%%%%%%%%%%%%

\renewcommand\thesection{\@arabic\c@section}
\renewcommand\thesubsection{\thesection.\@arabic\c@subsection}

\renewcommand\@seccntformat[1]{\csname the#1\endcsname.\hspace{0.5em}}
 
\renewcommand\section{ \@startsection{section}{1}{\z@}%
                          {-3.25ex\@plus -1ex \@minus -.2ex}%
                          {+1em \@plus .2ex }%
                          {\sf \large}}

\renewcommand\subsection{ \@startsection{subsection}{2}{\z@}%
                          {-3.25ex\@plus -1ex \@minus -.2ex}%
                          {+0.5em \@plus .2ex}%
                          {\sf }}

\renewcommand\subsubsection{ \@startsection{subsubsection}{3}{\z@}%
                          {-3.25ex\@plus -1ex \@minus -.2ex}%
                          {0em \@plus .2ex}%
                          {\sf }}

%%%%%%%%%%%%%%%%%%%%% Figures and tables %%%%%%%%%%%%%%%%%%%%%%%%

\def\fnum@figure{Fig.~\thefigure}
\def\fnum@table{Table~\thetable}

\newlength{\captionindent}
\long\def\@makecaption#1#2#3{
    \vskip 5pt
    \setbox\@tempboxa\hbox{\small \sf #1.~#2}
    \ifdim \wd\@tempboxa >\hsize
       \setbox\@tempboxa\hbox{\small \sf #1.~}
       \setlength\captionindent{\wd\@tempboxa} \divide\captionindent by 2
       \addtolength{\hsize}{-\wd\@tempboxa}%
       \mbox{\small \sf #1.~}\parbox[t]{\hsize}{\small \sf #2}
    \else 
       \textbf{\small \sf #1.~#2}
    \fi
}

%%%%%%%%%%%%%%%%%%%%%%%%%% Paragraphs %%%%%%%%%%%%%%%%%%%%%%%%
\setlength\parindent{0em}
%\setlength\parskip{1em}

%%%%%%%%%%%%%%%%%%%%%%%%%% Bibliography %%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand\bibname{References}

\renewenvironment{thebibliography}[1]
     {\section*{\bibname}%
      \@mkboth{\MakeUppercase\bibname}{\MakeUppercase\bibname}%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
      